#
# spec file for package distribution-gpg-keys
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2021 Nicolas FORMICHELLA <stigpro@outlook.fr>
# Copyright (c) 2022 Neal Gompa <ngompa13@gmail.com>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Release versions are part of the git tag
%global origrel 1

Name:           distribution-gpg-keys
Version:        1.88
Release:        1.1
Summary:        GPG keys of various Linux distributions
Group:          System/Packages
License:        CC0-1.0
URL:            https://github.com/xsuchy/distribution-gpg-keys
Source0:        %{url}/archive/%{name}-%{version}-%{origrel}.tar.gz
BuildArch:      noarch

%description
GPG keys used by various Linux distributions to sign packages.

%prep
%setup -q -n %{name}-%{name}-%{version}-%{origrel}

%build
#nothing to do here

%install
mkdir -p %{buildroot}%{_datadir}/%{name}/
cp -a keys/* %{buildroot}%{_datadir}/%{name}/

# We don't want to package COPR GPG keys
rm -rf %{buildroot}%{_datadir}/%{name}/copr

%files
%license LICENSE
%doc README.md SOURCES.md
%{_datadir}/%{name}/

%changelog
* Mon Jun 12 2023 Luciano Santos <luc14n0@opensuse.org>
- Update to v1.88
  + Update copr keys
  + Add per distro/version link to proper key for remi
  + Update brave keys
  + Add Docker key
  + Add mullvad key
- Changes from v1.87
  + Update copr keys
  + Update virtualbox key
  + Update openSUSE-Backports key
  + Update skype key
- Changes from v1.86
  + Update copr keys
  + Add Jenkins 2023
  + Add keys for Bacula & Baculum
  + Add keys for Google Cloud
  + Add VeraCrypt keys
  + Add Element keys
- Changes from v1.85
  + Update copr keys
  + Add Amazon Linux 2023 and remove Amazon Linux 2022 key
  + Add AnyDesk GPG key
- Changes from v1.84
  + Add tumbleweed key
  + Add RPM Fusion keys for Fedora 39
  + Update copr keys
  + Add elastic gpg key
- Changes from v1.82
  + Move symlink of fedora-rawhide to fedora-39
  + Add openEuler new key
  + Update copr keys
  + Add fedora 40 gpg key
- Changes from v1.81
  + Update copr keys
  + Add remi 2023 key
  + Add TeamViewer key
- Changes from v1.80
  + Add SME Server keys
  + Update copr keys
* Wed Dec 14 2022 Luciano Santos <luc14n0@opensuse.org>
- Update to v1.79
  + Fix Fedora 39 key
  + Add openEuler GPG key
  + Add Oracle Linux 9 key
  + Add Fedora 10 key
  + Add f37 to releasers
  + Add Fedora 38 and 39 keys
  + Add Amazon Linux 2022 GPG key
  + Add Anolis OS GPG keys
  + Remove F34 from releasers
  + Add Circle Linux GPG keys
  + Add Rocky Linux 9 keys and refresh 8
* Tue May 24 2022 Neal Gompa <ngompa13@gmail.com>
- Update to v1.71
  + Refresh AlmaLinux keys to add AlmaLinux 9 key
  + Add RHEL9 keys
  + Add RPM Fusion keys for Fedora 38
  + Add RPM Fusion keys for EL 9
* Wed Mar 23 2022 Neal Gompa <ngompa13@gmail.com>
- Update to v1.67
  + Add EPEL9 key
  + Add keys of RPM Fusion Fedora 37
  + Add Navy Linux RPM GPG official key
  + add new MySQL key
  + add Fedora 37
  + Add symlink for CentOS Stream 9 to main official key
  + Add EuroLinux 9 key
  + move Fedora Rawhide key to F37
  + Add remi 2022 key
  + Refresh all CentOS SIG keys (rh#2059424)
* Fri Oct 22 2021 Nicolas FORMICHELLA <stigpro@outlook.fr>
- Update to v1.58
  - [1.39]
    + Add Rosa Linux and Intel keys
  - [1.40]
    + Add EuroLinux keys
    + Add Datto's third party repository keys
  - [1.41]
    + Add QubesOS and Fedora 34 keys
  - [1.42]
    + Add RPMFusion 33 keys
  - [1.43]
  - [1.44]
    + Add Oracle Linux, Fedora ELN and Zoom keys
    + Update symlinks
  - [1.45]
    + Update symlinks
  - [1.46]
  - [1.47]
    + Add Remi 2021 key
  - [1.48]
    + Add Fedora 35 keys
  - [1.49]
    + Add Mariadb and Alma Linux keys
    + Update symlinks
  - [1.50]
  - [1.51]
    + Add Intel new key
    + Add Fedora 36 key
    + Add missing CentOS keys
  - [1.52-1.53]
  - [1.54]
    + Add SUSE keys
    + Add OpenSUSE
  - [1.55]
    + Add Rocky Linux keys
  - [1.56-1.57]
  - [1.58]
    + Add RPMFusion 36 keys
    + Update symlinks
* Thu May 21 2020 Neal Gompa <ngompa13@gmail.com>
- Version 1.38
  + Add Fedora GPG keys for Fedora 33
  + Add symlinks for CentOS 8 GPG keys
  + Add various vendor repository GPG keys
* Sat Dec  7 2019 Neal Gompa <ngompa13@gmail.com>
- Version 1.35
  + Add Fedora GPG keys for Fedora 32
  + Add CentOS 8 and EPEL 8 GPG keys
  + Add Amazon Linux 2 GPG key
  + Add OpenMandriva GPG key
  + Add various vendor repository GPG keys
* Mon Feb 25 2019 Neal Gompa <ngompa13@gmail.com>
- Version 1.29
  + Add Fedora GPG keys for Fedora 30 and 31
  + Add Fedora GPG key for IoT Edition
  + Add Red Hat Enterprise Linux 8 Beta GPG keys
  + Add various vendor repository GPG keys
* Mon Apr 30 2018 Neal Gompa <ngompa13@gmail.com>
- Version 1.21
- Initial package based on Mageia packaging
